@@ -66,7 +66,3 @@ def main():
             if (args.groups is None) or (argmax[0] in args.groups):
                 if len(nonmax) == 0 or sum(nonmax) <= args.tolerance:
                     vcf_out.write(rec)
-
-
-if __name__ == '__main__':
-    main()
